@@ -17,7 +17,7 @@ namespace Btctl.Test {
 			Controller ctl = new Controller ();
 
 			Console.WriteLine ("Asking if initialised");
-			if (ctl.IsInitialised) {
+			if (ctl.IsInitialised()) {
 				Console.WriteLine ("Yes, is initialised");
 			}
 
