@@ -2,8 +2,6 @@
 #define _BTCTL_DISCOVERY_SOURCE_H
 
 #include <sys/socket.h>
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/hci.h>
 
 #include <glib.h>
 
@@ -11,14 +9,6 @@ G_BEGIN_DECLS
 
 typedef struct _BtctlDiscoverySource BtctlDiscoverySource;
 
-struct _BtctlDiscoverySource {
-    GSource gsource;
-    GPollFD fd;
-    guchar buf[HCI_MAX_EVENT_SIZE];
-    gint len;
-    gboolean initialised;
-};
-
 typedef gboolean (*BtctlDiscoverySourceFunc) 
     (BtctlDiscoverySource *source, gpointer data);
 
@@ -34,6 +24,7 @@ BtctlDiscoverySource * btctl_discovery_source_new (void);
 void btctl_discovery_source_set_callback (BtctlDiscoverySource *source,
         BtctlDiscoverySourceFunc func, gpointer data,
         GDestroyNotify notify);
+gboolean btctl_discovery_source_is_initialised (BtctlDiscoverySource *source);
 
 G_END_DECLS
 
