@@ -1091,7 +1091,7 @@ btctl_controller_impl_get_discoverable(BtctlController *bc, GError **err)
 	if ((ctl = socket(AF_BLUETOOTH, SOCK_RAW, BTPROTO_HCI)) < 0) {
 		g_set_error (err, btctl_error_quark(),
 			     BTCTL_ERROR_NO_BLUETOOTH_DEVICE,
-			     "Can't open HCI socket: %s (%s)",
+			     "Can't open HCI socket: %s (%d)",
 			     strerror(errno), errno);
 		return FALSE;
 	}
@@ -1122,7 +1122,7 @@ btctl_controller_impl_set_discoverable(BtctlController *bc,
 	if ((ctl = socket(AF_BLUETOOTH, SOCK_RAW, BTPROTO_HCI)) < 0) {
 		g_set_error (err, btctl_error_quark(),
 			     BTCTL_ERROR_NO_BLUETOOTH_DEVICE,
-			     "Can't open HCI socket: %s (%s)",
+			     "Can't open HCI socket: %s (%d)",
 			     strerror(errno), errno);
 		return;
 	}
