@@ -50,13 +50,13 @@ struct _BtctlObex
 struct _BtctlObexClass
 {
   GObjectClass	parent_class;
-  void (* request_put) (BtctlObex *bc, gchar *bdaddr);
-  void (* put) (BtctlObex *bc, gchar *bdaddr, gchar *fname, BtctlObexData *data, guint timestamp);
-  void (* progress) (BtctlObex *bc, gchar *bdaddr);
-  void (* complete) (BtctlObex *bc, gchar *bdaddr);
-  void (* error) (BtctlObex *bc, gchar *bdaddr, guint code);
-  void (* connect) (BtctlObex *bc, gchar *bdaddr);
-  void (* disconnect) (BtctlObex *bc, gchar *bdaddr);
+  void (* request_put) (BtctlObex *bc, const gchar *bdaddr);
+  void (* put) (BtctlObex *bc, const gchar *bdaddr, const gchar *fname, BtctlObexData *data, guint timestamp);
+  void (* progress) (BtctlObex *bc, const gchar *bdaddr);
+  void (* complete) (BtctlObex *bc, const gchar *bdaddr);
+  void (* error) (BtctlObex *bc, const gchar *bdaddr, guint code);
+  void (* connect) (BtctlObex *bc, const gchar *bdaddr);
+  void (* disconnect) (BtctlObex *bc, const gchar *bdaddr);
 };
 
 /* Gtk housekeeping methods */
