@@ -449,7 +449,7 @@ btctl_obexclient_source_new (gchar *bdaddr, gint channel)
     gchar *destaddr;
 
     g_return_val_if_fail (bdaddr != NULL, NULL);
-    g_return_val_if_fail (channel <= 0, NULL);
+    g_return_val_if_fail (channel > 0, NULL);
 
     destaddr = g_ascii_strup (bdaddr, strlen(bdaddr));
 
